package models

//药房表
type Pharmary struct {
	ID         int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId  int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId  int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Ctime      int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime      int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Status     int64 `gorm:"column:status" json:"status" form:"status"`
	RecordDate int64 `gorm:"column:record_date" json:"record_date" form:"record_date"`
}

func (Pharmary) TableName() string {
	return "sgj_xt.xt_pharmacy"
}

type XtErrs struct {
	OrgId     int64  `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Route     string `gorm:"column:route" json:"route" form:"route"`
	Parameter string `gorm:"column:parameter" json:"parameter" form:"parameter"`
	Text_err  string `gorm:"column:text_err" json:"text_err" form:"text_err"`
}

func (XtErrs) TableName() string {
	return "sgj_xt.xt_errs"
}

//病人
type TmpPatient struct {
	PatientID  int64
	Name       string
	DialysisNo string //透析号
}

//药品信息
type PharmacyContent struct {
	Name         string //名称
	SingleDosage string //单次用量
	Usage        string //用法
	Frequency    string //频率
	Days         string //天数
	Total        string //总量
	Doctor       string //开立医生
	DataSources  string //数据来源
	Remarks      string //备注
}

//发药明细列表
type DispensingList struct {
	PatientID  int64  //	患者id
	Name       string //患者姓名
	DoctorId   int64  //医生id
	DoctorName string //医生姓名
	RecordTime int64  //发药时间(转化前)
	RecordDate string //发药时间(转化后)
}
type PrescripDetailsList struct {
	Name string //处方名
	Id   int64  //处方id
	Pres []*PrescripDetails
}

//处方详情
type PrescripDetails struct {
	Drugname     string //药品名称
	SingleDosage string //单次用量
	Usage        string //用法
	Frequency    string //频率
	Days         string //天数
	Total        string //总量
	UnitPrice    string //单价
	Remarks      string //备注
}

//临时医嘱
type StatOrder struct {
	StartTime             string //开始时间
	Name                  string //医嘱名称
	Specifications        string //药品规格
	PreQuantity           string //开药数量
	SingleDosage          string //单次用量
	RouteOfAdministration string //给药途径
	ExecutionFrequency    string //执行频率
}

//退库用的结构体
type SpecialForStock struct {
	BatchNumber       string      `json:"batch_number"`
	BatchNumberId     int64       `json:"batch_number_id"`
	Dealer            string      `json:"dealer"`
	DrugId            int64       `json:"drug_id"`
	DrugName          string      `json:"drug_name"`
	DrugType          int64       `json:"drug_type"`
	DrugWarehouseInfo interface{} `json:"drug_warehouse_info"`
	ExpiryDate        string      `json:"expiry_date"`
	LastPrice         float64     `json:"last_price"`
	Manufacturer      string      `json:"manufacturer"`
	MaxUnit           string      `json:"max_unit"`
	MinUnit           string      `json:"min_unit"`
	Name              string      `json:"name"`
	Price             string      `json:"price"`
	ProductDate       string      `json:"product_date"`
	RegisterAccount   string      `json:"register_account"`
	Remark            string      `json:"remark"`
	RetailPrice       string      `json:"retail_price"`
	ReturnCount       string      `json:"return_count"`
}

//药品发药药品列表
type ListOfDrugs struct {
	ID             int64  `json:"id"`             //药品id
	Name           string `json:"name"`           //药品 名称
	Specifications string `json:"specifications"` //规格
	Stock          string `json:"stock"`          //库存（当前的仓库库存）
}

//病人信息
type PatientInformation struct {
	Id           string `json:"id"`            //hid表示his_doctor_advice_info的id ,xid表示xt_doctor_advice的id
	PatientId    int64  `json:"patient_id"`    //患者id
	Name         string `json:"name"`          //患者姓名
	SingleDosage string `json:"single_dosage"` //单次用量
	Usage        string `json:"usage"`         //用法
	Frequency    string `json:"frequency"`     //频率
	Days         string `json:"days"`          //天数
	Total        string `json:"total"`         //总量
	DataSources  string `json:"data_sources"`  //数据来源
	People       string `json:"people"`        //领药人
	Quantity     int64  `json:"quantity"`      //总量拆分——数据部分
	Unit         string `json:"unit"`          //总量拆分——单位部分
}
type HisDoctorAdviceInfoL struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId          int64   `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	AdviceType            int64   `gorm:"column:advice_type" json:"advice_type" form:"advice_type"`
	AdviceDate            int64   `gorm:"column:advice_date" json:"advice_date" form:"advice_date"`
	StartTime             int64   `gorm:"column:start_time" json:"start_time" form:"start_time"`
	AdviceName            string  `gorm:"column:advice_name" json:"advice_name" form:"advice_name"`
	AdviceDesc            string  `gorm:"column:advice_desc" json:"advice_desc" form:"advice_desc"`
	ReminderDate          int64   `gorm:"column:reminder_date" json:"reminder_date" form:"reminder_date"`
	SingleDose            float64 `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	SingleDoseUnit        string  `gorm:"column:single_dose_unit" json:"single_dose_unit" form:"single_dose_unit"`
	PrescribingNumber     float64 `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	PrescribingNumberUnit string  `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DeliveryWay           string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency    string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	AdviceDoctor          int64   `gorm:"column:advice_doctor" json:"advice_doctor" form:"advice_doctor"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime           int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime           int64   `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	AdviceAffirm          string  `gorm:"column:advice_affirm" json:"advice_affirm" form:"advice_affirm"`
	Remark                string  `gorm:"column:remark" json:"remark" form:"remark"`
	StopTime              int64   `gorm:"column:stop_time" json:"stop_time" form:"stop_time"`
	StopReason            string  `gorm:"column:stop_reason" json:"stop_reason" form:"stop_reason"`
	StopDoctor            int64   `gorm:"column:stop_doctor" json:"stop_doctor" form:"stop_doctor"`
	StopState             int64   `gorm:"column:stop_state" json:"stop_state" form:"stop_state"`
	ParentId              int64   `gorm:"column:parent_id" json:"parent_id" form:"parent_id"`
	ExecutionTime         int64   `gorm:"column:execution_time" json:"execution_time" form:"execution_time"`
	ExecutionStaff        int64   `gorm:"column:execution_staff" json:"execution_staff" form:"execution_staff"`
	ExecutionState        int64   `gorm:"column:execution_state" json:"execution_state" form:"execution_state"`
	Checker               int64   `gorm:"column:checker" json:"checker" form:"checker"`
	RecordDate            int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DialysisOrderId       int64   `gorm:"column:dialysis_order_id" json:"dialysis_order_id" form:"dialysis_order_id"`
	CheckTime             int64   `gorm:"column:check_time" json:"check_time" form:"check_time"`
	CheckState            int64   `gorm:"column:check_state" json:"check_state" form:"check_state"`
	DrugSpec              float64 `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugSpecUnit          string  `gorm:"column:drug_spec_unit" json:"drug_spec_unit" form:"drug_spec_unit"`
	Groupno               int64   `gorm:"column:groupno" json:"groupno" form:"groupno"`
	RemindType            int64   `gorm:"column:remind_type" json:"remind_type" form:"remind_type"`
	FrequencyType         int64   `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount              int64   `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay               string  `gorm:"column:week_day" json:"week_day" form:"week_day"`
	TemplateId            string  `gorm:"column:template_id" json:"template_id" form:"template_id"`
	Modifier              int64   `gorm:"column:modifier" json:"modifier" form:"modifier"`
	DrugId                int64   `gorm:"column:drug_id" json:"drug_id" form:"drug_id"`
	Price                 float64 `gorm:"column:price" json:"price" form:"price"`
	PrescriptionId        int64   `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	MedListCodg           string  `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	FeedetlSn             string  `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	Day                   int64   `gorm:"column:day" json:"day" form:"day"`
	Diagnosis             int64   `gorm:"column:diagnosis" json:"diagnosis" form:"diagnosis"`
	Way                   int64   `gorm:"column:way" json:"way" form:"way"`
	HospApprFlag          int64   `gorm:"column:hosp_appr_flag" json:"hosp_appr_flag" form:"hosp_appr_flag"`
	LmtUsedFlag           int64   `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
	IsMedicine            int64   `gorm:"column:is_medicine" json:"is_medicine" form:"is_medicine"`
	People                int64   `gorm:"column:people" json:"people" form:"people"`
	DispensingTime        int64   `gorm:"column:dispensing_time" json:"dispensing_time" form:"dispensing_time"`
}

func (HisDoctorAdviceInfoL) TableName() string {
	return "sgj_xt.his_doctor_advice_info"
}

type XtDoctorAdviceL struct {
	ID                    int64   `gorm:"column:id" json:"id" form:"id"`
	UserOrgId             int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId             int64   `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	AdviceType            int64   `gorm:"column:advice_type" json:"advice_type" form:"advice_type"`
	AdviceDate            int64   `gorm:"column:advice_date" json:"advice_date" form:"advice_date"`
	StartTime             int64   `gorm:"column:start_time" json:"start_time" form:"start_time"`
	AdviceName            string  `gorm:"column:advice_name" json:"advice_name" form:"advice_name"`
	AdviceDesc            string  `gorm:"column:advice_desc" json:"advice_desc" form:"advice_desc"`
	ReminderDate          int64   `gorm:"column:reminder_date" json:"reminder_date" form:"reminder_date"`
	SingleDose            float64 `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	SingleDoseUnit        string  `gorm:"column:single_dose_unit" json:"single_dose_unit" form:"single_dose_unit"`
	PrescribingNumber     float64 `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	PrescribingNumberUnit string  `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DeliveryWay           string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency    string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	AdviceDoctor          int64   `gorm:"column:advice_doctor" json:"advice_doctor" form:"advice_doctor"`
	Status                int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime           int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime           int64   `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	AdviceAffirm          string  `gorm:"column:advice_affirm" json:"advice_affirm" form:"advice_affirm"`
	Remark                string  `gorm:"column:remark" json:"remark" form:"remark"`
	StopTime              int64   `gorm:"column:stop_time" json:"stop_time" form:"stop_time"`
	StopReason            string  `gorm:"column:stop_reason" json:"stop_reason" form:"stop_reason"`
	StopDoctor            int64   `gorm:"column:stop_doctor" json:"stop_doctor" form:"stop_doctor"`
	StopState             int64   `gorm:"column:stop_state" json:"stop_state" form:"stop_state"`
	ParentId              int64   `gorm:"column:parent_id" json:"parent_id" form:"parent_id"`
	ExecutionTime         int64   `gorm:"column:execution_time" json:"execution_time" form:"execution_time"`
	ExecutionStaff        int64   `gorm:"column:execution_staff" json:"execution_staff" form:"execution_staff"`
	ExecutionState        int64   `gorm:"column:execution_state" json:"execution_state" form:"execution_state"`
	Checker               int64   `gorm:"column:checker" json:"checker" form:"checker"`
	RecordDate            int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DialysisOrderId       int64   `gorm:"column:dialysis_order_id" json:"dialysis_order_id" form:"dialysis_order_id"`
	CheckTime             int64   `gorm:"column:check_time" json:"check_time" form:"check_time"`
	CheckState            int64   `gorm:"column:check_state" json:"check_state" form:"check_state"`
	DrugSpec              float64 `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugSpecUnit          string  `gorm:"column:drug_spec_unit" json:"drug_spec_unit" form:"drug_spec_unit"`
	Groupno               int64   `gorm:"column:groupno" json:"groupno" form:"groupno"`
	RemindType            int64   `gorm:"column:remind_type" json:"remind_type" form:"remind_type"`
	FrequencyType         int64   `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount              int64   `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay               string  `gorm:"column:week_day" json:"week_day" form:"week_day"`
	TemplateId            string  `gorm:"column:template_id" json:"template_id" form:"template_id"`
	UserName              string  `gorm:"column:user_name" json:"user_name" form:"user_name"`
	CheckerName           string  `gorm:"column:user_name" json:"name" form:"name"`
	Modifier              int64   `gorm:"column:modifier" json:"modifier" form:"modifier"`
	IsMedicine            int64   `gorm:"column:is_medicine" json:"is_medicine" form:"is_medicine"`
	People                int64   `gorm:"column:people" json:"people" form:"people"`
	DispensingTime        int64   `gorm:"column:dispensing_time" json:"dispensing_time" form:"dispensing_time"`
}

func (XtDoctorAdviceL) TableName() string {
	return "sgj_xt.xt_doctor_advice"
}

type TmpTTT struct {
	PatientID int64
}
type TmpLLL struct {
	DrugId int64
}
type TmpID struct {
	Id             int64
	DispensingTime int64
}
type TmpAdviceDoctor struct {
	AdviceDoctor int64
}

//替换药品名称
type ReplacementDrugs struct {
	Id   int64  `json:"id"`
	Name string `json:"name"`
}

//病人
type DialysisPatient struct {
	ID   int64  `json:"id"`
	Name string `json:"name"`
}

//项目下拉列表
type DropDownList struct {
	Id   string `json:"id"`
	Name string `json:"name"`
}
type XtHisProjectL struct {
	ID                          int64   `gorm:"column:id" json:"id" form:"id"`
	ProjectName                 string  `gorm:"column:project_name" json:"project_name" form:"project_name"`
	Pinyin                      string  `gorm:"column:pinyin" json:"pinyin" form:"pinyin"`
	Wubi                        string  `gorm:"column:wubi" json:"wubi" form:"wubi"`
	Price                       float64 `gorm:"column:price" json:"price" form:"price"`
	Unit                        string  `gorm:"column:unit" json:"unit" form:"unit"`
	CostClassify                int64   `gorm:"column:cost_classify" json:"cost_classify" form:"cost_classify"`
	ExecutiveSection            int64   `gorm:"column:executive_section" json:"executive_section" form:"executive_section"`
	MedicalCoverage             int64   `gorm:"column:medical_coverage" json:"medical_coverage" form:"medical_coverage"`
	StatisticalClassification   int64   `gorm:"column:statistical_classification" json:"statistical_classification" form:"statistical_classification"` //统计分类（组
	DiseaseDirectory            int64   `gorm:"column:disease_directory" json:"disease_directory" form:"disease_directory"`
	IsRecord                    int64   `gorm:"column:is_record" json:"is_record" form:"is_record"`
	MedicalCode                 string  `gorm:"column:medical_code" json:"medical_code" form:"medical_code"`
	TubeColor                   int64   `gorm:"column:tube_color" json:"tube_color" form:"tube_color"`
	MedicalStatus               int64   `gorm:"column:medical_status" json:"medical_status" form:"medical_status"`
	Remark                      string  `gorm:"column:remark" json:"remark" form:"remark"`
	Sign                        int64   `gorm:"column:sign" json:"sign" form:"sign"`
	DefaultNumber               string  `gorm:"column:default_number" json:"prescribing_number" form:"default_number"`
	IsDefault                   int64   `gorm:"column:is_default" json:"is_default" form:"is_default"`
	IsCharge                    int64   `gorm:"column:is_charge" json:"is_charge" form:"is_charge"`
	IsEstimate                  int64   `gorm:"column:is_estimate" json:"is_estimate" form:"is_estimate"`
	IsWorkload                  int64   `gorm:"column:is_workload" json:"is_workload" form:"is_workload"`
	Sort                        string  `gorm:"column:sort" json:"sort" form:"sort"`
	DoctorAdvice                int64   `gorm:"column:doctor_advice" json:"doctor_advice" form:"doctor_advice"`
	UserOrgId                   int64   `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status                      int64   `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                 int64   `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                 int64   `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	SingleDose                  string  `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	ExecutionFrequency          string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	DeliveryWay                 string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	NumberDays                  string  `gorm:"column:number_days" json:"day" form:"number_days"`
	Total                       string  `gorm:"column:total" json:"total" form:"total"`
	Category                    int64   `gorm:"column:category" json:"category" form:"category"`
	IsMark                      int64   `gorm:"column:is_mark" json:"is_mark" form:"is_mark"`
	SpecailProject              int64   `gorm:"column:specail_project" json:"specail_project" form:"specail_project"`
	SocialSecurityDirectoryCode string  `gorm:"column:social_security_directory_code" json:"social_security_directory_code" form:"social_security_directory_code"`
	RecordDate                  int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	Translate                   string  `json:"translate"` //翻译——统计分类（组
}

func (XtHisProjectL) TableName() string {
	return "sgj_xt.xt_his_project"
}

type GoodInfoL struct {
	ID                     int64   `gorm:"column:id" json:"id" form:"id"`
	GoodCode               string  `gorm:"column:good_code" json:"good_code" form:"good_code"`
	SpecificationName      string  `gorm:"column:specification_name" json:"specification_name" form:"specification_name"`
	GoodTypeId             int64   `gorm:"column:good_type_id" json:"good_type_id" form:"good_type_id"`
	GoodUnit               int64   `gorm:"column:good_unit" json:"good_unit" form:"good_unit"`
	BuyPrice               float64 `gorm:"column:buy_price" json:"buy_price" form:"buy_price"`
	SellPrice              float64 `gorm:"column:sell_price" json:"sell_price" form:"sell_price"`
	Remark                 string  `gorm:"column:remark" json:"remark" form:"remark"`
	Ctime                  int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                  int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Manufacturer           int64   `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	Dealer                 int64   `gorm:"column:dealer" json:"dealer" form:"dealer"`
	ExpiryDateWarnDayCount int64   `gorm:"column:expiry_date_warn_day_count" json:"expiry_date_warn_day_count" form:"expiry_date_warn_day_count"`
	StockWarnCount         int64   `gorm:"column:stock_warn_count" json:"stock_warn_count" form:"stock_warn_count"`
	IsReuse                int64   `gorm:"column:is_reuse" json:"is_reuse" form:"is_reuse"`
	Status                 int64   `gorm:"column:status" json:"status" form:"status"`
	FilmArea               string  `gorm:"column:film_area" json:"film_area" form:"film_area"`
	IsUse                  int64   `gorm:"column:is_use" json:"is_use" form:"is_use"`
	FilmMaterialQuality    string  `gorm:"column:film_material_quality" json:"film_material_quality" form:"film_material_quality"`
	OrgId                  int64   `gorm:"column:org_id" json:"org_id" form:"org_id"`
	Modifier               int64   `gorm:"column:modifier" json:"modifier" form:"modifier"`
	Creater                int64   `gorm:"column:creater" json:"creater" form:"creater"`
	GoodName               string  `gorm:"column:good_name" json:"good_name" form:"good_name"`
	Pinyin                 string  `gorm:"column:pinyin" json:"pinyin" form:"pinyin"`
	Wubi                   string  `gorm:"column:wubi" json:"wubi" form:"wubi"`
	GoodKind               int64   `gorm:"column:good_kind" json:"good_kind" form:"good_kind"` //组
	MedicalInsuranceLevel  int64   `gorm:"column:medical_insurance_level" json:"medical_insurance_level" form:"medical_insurance_level"`
	RetailPrice            float64 `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	MedicalInsuranceNumber string  `gorm:"column:medical_insurance_number" json:"medical_insurance_number" form:"medical_insurance_number"`
	ProvincesCode          string  `gorm:"column:provinces_code" json:"provinces_code" form:"provinces_code"`

	IsSpecialDiseases           int64                `gorm:"column:is_special_diseases" json:"is_special_diseases" form:"is_special_diseases"`
	IsRecord                    int64                `gorm:"column:is_record" json:"is_record" form:"is_record"`
	StatisticsCategory          int64                `gorm:"column:statistics_category" json:"statistics_category" form:"statistics_category"`
	GoodStatus                  string               `gorm:"column:good_status" json:"good_status" form:"good_status"`
	DefaultCount                int64                `gorm:"column:default_count" json:"default_count" form:"default_count"`
	Sign                        int64                `gorm:"column:sign" json:"sign" form:"sign"`
	IsDefault                   int64                `gorm:"column:is_default" json:"is_default" form:"is_default"`
	IsChargeUse                 int64                `gorm:"column:is_charge_use" json:"is_charge_use" form:"is_charge_use"`
	IsChargePredict             int64                `gorm:"column:is_charge_predict" json:"is_charge_predict" form:"is_charge_predict"`
	IsStatisticsWork            int64                `gorm:"column:is_statistics_work" json:"is_statistics_work" form:"is_statistics_work"`
	Sort                        int64                `gorm:"column:sort" json:"sort" form:"sort"`
	IsDoctorUse                 int64                `gorm:"column:is_doctor_use" json:"is_doctor_use" form:"is_doctor_use"`
	Agent                       string               `gorm:"column:agent" json:"agent" form:"agent"`
	GoodNumber                  string               `gorm:"column:good_number" json:"good_number" form:"good_number"`
	GoodsType                   GoodsType            `gorm:"ForeignKey:ID;AssociationForeignKey:GoodTypeId" json:"type"`
	CommdityCode                string               `gorm:"column:commdity_code" json:"commdity_code" form:"commdity_code"`
	SocialSecurityDirectoryCode string               `gorm:"column:social_security_directory_code" json:"social_security_directory_code" form:"social_security_directory_code"`
	ProductionType              string               `gorm:"column:production_type" json:"production_type" form:"production_type"`
	SpecialMedical              string               `gorm:"column:special_medical" json:"special_medical" form:"special_medical"`
	IsMark                      int64                `gorm:"column:is_mark" json:"is_mark" form:"is_mark"`
	MinNumber                   int64                `gorm:"column:min_number" json:"min_number" form:"min_number"`
	PackingUnit                 string               `gorm:"column:packing_unit" json:"packing_unit" form:"packing_unit"`
	PackingPrice                float64              `gorm:"column:packing_price" json:"packing_price" form:"packing_price"`
	DefaultCountUnit            string               `gorm:"column:default_count_unit" json:"default_count_unit" form:"default_count_unit"`
	MinUnit                     string               `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	Total                       float64              `gorm:"column:total" json:"total" form:"total"`
	StWarehousingInfo           []*StWarehousingInfo `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"xt_warehouse_info"`
	CancelStockInfo             []*CancelStockInfo   `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"cancel_stock_info"`
	RegisterNumber              string               `gorm:"column:register_number" json:"register_number" form:"register_number"`
	GoodSotckInfo               []*GoodSotckInfo     `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"good_stock_in"`
	IsUser                      int64                `gorm:"column:is_user" json:"is_user" form:"is_user"`
	Number                      string               `gorm:"column:number" json:"number" form:"number"`
	IsWarehouse                 int64                `gorm:"column:is_warehouse" json:"is_warehouse" form:"is_warehouse"`
	SumCount                    int64                `gorm:"column:sum_count" json:"sum_count" form:"sum_count"`
	BatchRetaiPrice             float64              `gorm:"column:batch_retai_price" json:"batch_retai_price" form:"batch_retai_price"`
	SumInCount                  int64                `gorm:"column:sum_in_count" json:"sum_in_count" form:"sum_in_count"`
	WarehousingInfo             []*WarehousingInfo   `gorm:"ForeignKey:GoodId;AssociationForeignKey:ID" json:"warehouse_info"`
	Translate                   string               `json:"translate"` //翻译——统计分类（组
}

func (GoodInfoL) TableName() string {
	return "sgj_xt.xt_good_information"
}

type BaseDrugLibL struct {
	ID                          int64   `gorm:"column:id" json:"id" form:"id"`
	DrugName                    string  `gorm:"column:drug_name" json:"drug_name" form:"drug_name"`
	Pinyin                      string  `gorm:"column:pinyin" json:"pinyin" form:"pinyin"`
	Wubi                        string  `gorm:"column:wubi" json:"wubi" form:"wubi"`
	DrugAlias                   string  `gorm:"column:drug_alias" json:"drug_alias" form:"drug_alias"`
	DrugAliasPinyin             string  `gorm:"column:drug_alias_pinyin" json:"drug_alias_pinyin" form:"drug_alias_pinyin"`
	DrugAliasWubi               string  `gorm:"column:drug_alias_wubi" json:"drug_alias_wubi" form:"drug_alias_wubi"`
	DrugCategory                int64   `gorm:"column:drug_category" json:"drug_category" form:"drug_category"`
	DrugSpec                    string  `gorm:"column:drug_spec" json:"drug_spec" form:"drug_spec"`
	DrugType                    int64   `gorm:"column:drug_type" json:"drug_type" form:"drug_type"`
	DrugStockLimit              string  `gorm:"column:drug_stock_limit" json:"drug_stock_limit" form:"drug_stock_limit"`
	DrugOriginPlace             string  `gorm:"column:drug_origin_place" json:"drug_origin_place" form:"drug_origin_place"`
	DrugDosageForm              int64   `gorm:"column:drug_dosage_form" json:"drug_dosage_form" form:"drug_dosage_form"`
	MedicalInsuranceLevel       int64   `gorm:"column:medical_insurance_level" json:"medical_insurance_level" form:"medical_insurance_level"`
	MaxUnit                     string  `gorm:"column:max_unit" json:"max_unit" form:"max_unit"`
	MinNumber                   int64   `gorm:"column:min_number" json:"min_number" form:"min_number"`
	MinUnit                     string  `gorm:"column:min_unit" json:"min_unit" form:"min_unit"`
	Dose                        string  `gorm:"column:dose" json:"dose" form:"dose"`
	DoseUnit                    string  `gorm:"column:dose_unit" json:"dose_unit" form:"dose_unit"`
	MinPrice                    float64 `gorm:"column:min_price" json:"min_price" form:"min_price"`
	UnitMatrixing               string  `gorm:"column:unit_matrixing" json:"unit_matrixing" form:"unit_matrixing"`
	RetailPrice                 float64 `gorm:"column:retail_price" json:"retail_price" form:"retail_price"`
	LastPrice                   float64 `gorm:"column:last_price" json:"last_price" form:"last_price"`
	DrugControl                 int64   `gorm:"column:drug_control" json:"drug_control" form:"drug_control"`
	Number                      string  `gorm:"column:number" json:"number" form:"number"`
	DrugClassify                string  `gorm:"column:drug_classify" json:"drug_classify" form:"drug_classify"`
	DrugDose                    float64 `gorm:"column:drug_dose" json:"drug_dose" form:"drug_dose"`
	DrugDoseUnit                int64   `gorm:"column:drug_dose_unit" json:"drug_dose_unit" form:"drug_dose_unit"`
	MedicalInsuranceNumber      string  `gorm:"column:medical_insurance_number" json:"medical_insurance_number" form:"medical_insurance_number"`
	ProvincesCode               string  `gorm:"column:provinces_code" json:"provinces_code" form:"provinces_code"`
	Manufacturer                int64   `gorm:"column:manufacturer" json:"manufacturer" form:"manufacturer"`
	PharmacologyCategory        int64   `gorm:"column:pharmacology_category" json:"pharmacology_category" form:"pharmacology_category"`
	StatisticsCategory          int64   `gorm:"column:statistics_category" json:"statistics_category" form:"statistics_category"`
	Code                        string  `gorm:"column:code" json:"code" form:"code"`
	IsSpecialDiseases           int64   `gorm:"column:is_special_diseases" json:"is_special_diseases" form:"is_special_diseases"`
	IsRecord                    int64   `gorm:"column:is_record" json:"is_record" form:"is_record"`
	Agent                       string  `gorm:"column:agent" json:"agent" form:"agent"`
	DrugStatus                  string  `gorm:"column:drug_status" json:"drug_status" form:"drug_status"`
	LimitRemark                 string  `gorm:"column:limit_remark" json:"limit_remark" form:"limit_remark"`
	DeliveryWay                 string  `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency          string  `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	SingleDose                  float64 `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	SingleDoseUnit              string  `json:"single_dose_unit"` //danwei
	PrescribingNumber           float64 `gorm:"column:prescribing_number" json:"prescribing_number" form:"prescribing_number"`
	Label                       int64   `gorm:"column:label" json:"label" form:"label"`
	Sort                        int64   `gorm:"column:sort" json:"sort" form:"sort"`
	IsUseDoctorAdvice           int64   `gorm:"column:is_use_doctor_advice" json:"is_use_doctor_advice" form:"is_use_doctor_advice"`
	IsDefault                   int64   `gorm:"column:is_default" json:"is_default" form:"is_default"`
	IsChargePredict             int64   `gorm:"column:is_charge_predict" json:"is_charge_predict" form:"is_charge_predict"`
	IsStatisticsWork            int64   `gorm:"column:is_statistics_work" json:"is_statistics_work" form:"is_statistics_work"`
	IsChargeUse                 int64   `gorm:"column:is_charge_use" json:"is_charge_use" form:"is_charge_use"`
	Status                      int64   `gorm:"column:status" json:"status" form:"status"`
	Ctime                       int64   `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                       int64   `gorm:"column:mtime" json:"mtime" form:"mtime"`
	OrgId                       int64   `gorm:"column:org_id" json:"org_id" form:"org_id"`
	DrugCode                    string  `gorm:"column:drug_code" json:"drug_code" form:"drug_code"`
	Dealer                      int64   `gorm:"column:dealer" json:"dealer" form:"dealer"`
	PrescriptionMark            int64   `gorm:"column:prescription_mark" json:"prescription_mark" form:"prescription_mark"`
	RecordDate                  int64   `gorm:"column:record_date" json:"record_date" form:"record_date"`
	DrugRemark                  string  `gorm:"column:drug_remark" json:"drug_remark" form:"drug_remark"`
	SocialSecurityDirectoryCode string  `gorm:"column:social_security_directory_code" json:"social_security_directory_code" form:"social_security_directory_code"`
	DoseCode                    string  `gorm:"column:dose_code" json:"dose_code" form:"dose_code"`
	IsMark                      int64   `gorm:"column:is_mark" json:"is_mark" form:"is_mark"`
	HospApprFlag                int64   `gorm:"column:hosp_appr_flag" json:"hosp_appr_flag" form:"hosp_appr_flag"`
	LmtUsedFlag                 int64   `gorm:"column:lmt_used_flag" json:"lmt_used_flag" form:"lmt_used_flag"`
	//MedicineInsurancePercentage []*MedicineInsurancePercentage `gorm:"ForeignKey:PatientId;AssociationForeignKey:PatientId" json:"monitoring_record"`
	DrugDay               string                 `gorm:"column:drug_day" json:"drug_day" form:"drug_day"`
	Total                 float64                `gorm:"column:total" json:"total" form:"total"`
	PrescribingNumberUnit string                 `gorm:"column:prescribing_number_unit" json:"prescribing_number_unit" form:"prescribing_number_unit"`
	DrugWarehouseInfo     []*XtDrugWarehouseInfo `gorm:"ForeignKey:DrugId;AssociationForeignKey:ID" json:"drug_warehouse_info"`
	IsUse                 int64                  `gorm:"column:is_user" json:"is_user" form:"is_user"`
	BatchRetaiPrice       float64                `gorm:"column:batch_retai_price" json:"batch_retai_price" form:"batch_retai_price"`
	SumCount              int64                  `gorm:"column:sum_count" json:"sum_count" form:"sum_count"`
	SumInCount            int64                  `gorm:"column:sum_in_count" json:"sum_in_count" form:"sum_in_count"`
	IsPharmacy            int64                  `gorm:"column:is_pharmacy" json:"is_pharmacy" form:"is_pharmacy"`
	List1                 interface{}            `json:"list_1"`
	List2                 interface{}            `json:"list_2"`
}

func (BaseDrugLibL) TableName() string {
	return "xt_base_drug"
}

//组
type HisPrescriptionInfoTemplateL struct {
	ID                             int64                              `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                      int64                              `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	RecordDate                     int64                              `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PatientId                      int64                              `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Status                         int64                              `gorm:"column:status" json:"status" form:"status"`
	Ctime                          int64                              `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                          int64                              `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Type                           int64                              `gorm:"column:type" json:"type" form:"type"`
	Creator                        int64                              `gorm:"column:creator" json:"creator" form:"creator"`
	Modifier                       int64                              `gorm:"column:modifier" json:"modifier" form:"modifier"`
	PType                          int64                              `gorm:"column:p_type" json:"p_type" form:"p_type"`
	PTemplateId                    int64                              `gorm:"column:p_template_id" json:"p_template_id" form:"p_template_id"`
	HisPrescriptionAdviceTemplate  []*HisPrescriptionAdviceTemplate   `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"advices"`
	HisPrescriptionProjectTemplate []*HisPrescriptionProjectTemplateL `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"project"`
	MedType                        string                             `gorm:"column:med_type" json:"med_type" form:"med_type"`
}

func (HisPrescriptionInfoTemplateL) TableName() string {
	return "his_prescription_info_template"
}

type HisPrescriptionProjectTemplateL struct {
	ID                 int64         `gorm:"column:id" json:"id" form:"id"`
	ProjectId          int64         `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Price              float64       `gorm:"column:price" json:"price" form:"price"`
	UserOrgId          int64         `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status             int64         `gorm:"column:status" json:"status" form:"status"`
	Ctime              int64         `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime              int64         `gorm:"column:mtime" json:"mtime" form:"mtime"`
	PatientId          int64         `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId       int64         `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	RecordDate         int64         `gorm:"column:record_date" json:"record_date" form:"record_date"`
	Count              string        `gorm:"column:count" json:"count" form:"count"`
	FeedetlSn          string        `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	MedListCodg        string        `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	SingleDose         string        `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	DeliveryWay        string        `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency string        `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	Day                string        `gorm:"column:day" json:"day" form:"day"`
	Remark             string        `gorm:"column:remark" json:"remark" form:"remark"`
	Unit               string        `gorm:"column:unit" json:"unit" form:"unit"`
	Type               int64         `gorm:"column:type" json:"type" form:"type"`
	PrescriptionId     int64         `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	XtHisProject       XtHisProjectL `gorm:"ForeignKey:ID;AssociationForeignKey:ProjectId" json:"project"`
	GoodInfo           GoodInfoL     `gorm:"ForeignKey:ID;AssociationForeignKey:ProjectId" json:"good_info"`
	FrequencyType      int64         `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount           int64         `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay            string        `gorm:"column:week_day" json:"week_day" form:"week_day"`
}

func (HisPrescriptionProjectTemplateL) TableName() string {
	return "his_prescription_project_template"
}
